# TobiiGlassesPySuite
The TobiiGlassesPySuite is an open-source Python toolkit for exploiting the capabilities of the Tobii Pro Glasses 2 in cross-platform environments.

# Compatibility

Python 2.x and Python 3.x

GNU/Linux, MacOS, Windows OS

# Installing


```
pip install tobiiglasses
```

# Getting started

Please visit the wiki.


# Citation

Davide De Tommaso and Agnieszka Wykowska. 2019. TobiiGlassesPySuite: An open-source suite for using the Tobii Pro Glasses 2 in eye-tracking studies. In 2019 Symposium on Eye Tracking Research and Applications (ETRA ’19), June 25–28, 2019, Denver , CO, USA. ACM, New York, NY, USA, 5 pages. https://doi.org/10.1145/3314111.3319828


```
@inproceedings{DeTommaso:2019:TOS:3314111.3319828,
 author = {De Tommaso, Davide and Wykowska, Agnieszka},
 title = {TobiiGlassesPySuite: An Open-source Suite for Using the Tobii Pro Glasses 2 in Eye-tracking Studies},
 booktitle = {Proceedings of the 11th ACM Symposium on Eye Tracking Research \& Applications},
 series = {ETRA '19},
 year = {2019},
 isbn = {978-1-4503-6709-7},
 location = {Denver, Colorado},
 pages = {46:1--46:5},
 articleno = {46},
 numpages = {5},
 url = {http://doi.acm.org/10.1145/3314111.3319828},
 doi = {10.1145/3314111.3319828},
 acmid = {3319828},
 publisher = {ACM},
 address = {New York, NY, USA},
 keywords = {Tobii Pro Glasses 2, eye-tracking, human-computer interaction, open-source, wearable computing, wearable eye-tracker},
} 
```
